@@ -13,7 +13,14 @@ class modes():
     DEFAULT = 'default',
 
 
-metadata_api_base = "http://url-metadata.herokuapp.com"
+class parser_actions:
+    LIST_QUESTIONS_OF_TAGS = 1,
+    OPEN_QUESTIONS = 2,
+    LIST_TAGS = 3,
+    ADD_QUESTIONS_TO_TAGS = 4
+
+
+metadata_api_base = "http =//url-metadata.herokuapp.com"
 
 # colored text
 
