@@ -8,8 +8,9 @@ switcher = None
 # questions_list = [22, 23, 12, 232, 2]
 questions_list = []
 tags = []
+parser_action = None
 cursor = None
-
+conn = None
 # when listing things, how many records to show, defaults to 10
 how_many = 10
 
